VideoTextPosition enum
Position of text for video progress
Values
- ltl → const VideoTextPosition
-
Are located on the left side of the progress bar.
- rtr → const VideoTextPosition
-
Are located on the right side of the progress bar.
- ltr → const VideoTextPosition
-
The current progress is to the left of the progress bar. The total duration is on the right side of the progress bar.
- none → const VideoTextPosition
-
Do not display.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VideoTextPosition> - A constant List of the values in this enum, in order of their declaration.